@@ -1,11 +1,11 @@
 #!/bin/sh
 export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
 echo 'name: StateVar
-version: 1.1.0.3
-id: StateVar-1.1.0.3-dfbaaa5b80efc1d36dff08b16817e21d
-key: State_8WYLUQJECQz8PFb9p2aPSq
+version: 1.1.0.4
+id: StateVar-1.1.0.4-fc65b0726880e394d3716252d743e7fc
+key: State_IOvB80WkYNkEizdt0JVpzy
 license: BSD3
-copyright: Copyright (C) 2014-2015 Edward A. Kmett, 2009-2015 Sven Panne
+copyright: Copyright (C) 2014-2015 Edward A. Kmett, 2009-2016 Sven Panne
 maintainer: Sven Panne <svenpanne@gmail.com>
 homepage: https://github.com/haskell-opengl/StateVar
 synopsis: State variables
@@ -18,10 +18,10 @@ exposed: True
 exposed-modules:
     Data.StateVar
 trusted: False
-import-dirs: /usr/lib/ghc-7.10.3/site-local/StateVar-1.1.0.3
-library-dirs: /usr/lib/ghc-7.10.3/site-local/StateVar-1.1.0.3
-data-dir: /usr/share/arm-linux-ghc-7.10.3/StateVar-1.1.0.3
-hs-libraries: HSStateVar-1.1.0.3-8WYLUQJECQz8PFb9p2aPSq
+import-dirs: /usr/lib/ghc-7.10.3/site-local/StateVar-1.1.0.4
+library-dirs: /usr/lib/ghc-7.10.3/site-local/StateVar-1.1.0.4
+data-dir: /usr/share/arm-linux-ghc-7.10.3/StateVar-1.1.0.4
+hs-libraries: HSStateVar-1.1.0.4-IOvB80WkYNkEizdt0JVpzy
 depends:
     base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
     stm-2.4.4.1-b43e402fc74ce6b0320fe4217e7e432d
